@@ -23,12 +23,15 @@ CONSUMER_SECRET = os.getenv('TWITTER_CONSUMER_SECRET')
 ACCESS_TOKEN_KEY = os.getenv('TWITTER_ACCESS_TOKEN_KEY')
 ACCESS_TOKEN_SECRET = os.getenv('TWITTER_ACCESS_TOKEN_SECRET')
 SPACE_REGEX = re.compile(r"[ \n]{2,}")
+ITEM_REGEX = re.compile(r"^[0-9]{1,3}.\W+")
+EMPTY_REGEX = re.compile(r"^[, ]$")
+DOT_REGEX = re.compile(r"^·\W+")
 ES_ENABLED = os.environ.get('ES_ENABLED', 'False') == 'True'
 TWITTER_ENABLED = os.getenv('TWITTER_ENABLED', 'False') == 'True'
 
 
 class SantaMonicaScraper(EngageScraper):
-    def __init__(self, tz_string="America/Los_Angeles", years=["2019"]):
+    def __init__(self, tz_string="America/Los_Angeles", years=["2020"], test=False):
         super().__init__(tz_string)
 
         # Requests/HTML session
@@ -55,6 +58,7 @@ class SantaMonicaScraper(EngageScraper):
         # Instantiate elasticsearch utility object
         if ES_ENABLED:
             self._elasticsearch_utility = ElasticsearchUtility()
+        self._test = test
 
     @property
     def agendas_table_location(self):
@@ -177,6 +181,8 @@ class SantaMonicaScraper(EngageScraper):
                             if TWITTER_ENABLED:
                                 self._twitter_util.tweet(
                                     "Agenda Items for the next @santamonicacity City Council meeting is open for public feedback until 11:59:59AM {}. Head to http://sm.engage.town now to voice your opinion!".format(newdate[1]))
+                        if self._test and len(processed_data["items"]) > 2:
+                            break
 
     def _process_agenda(self, agenda_data, meeting_id):
         date_time_string = agenda_data.find(
@@ -280,11 +286,9 @@ class SantaMonicaScraper(EngageScraper):
         # font-family:Arial; font-size:12pt is recommendations
         # Span's not equal to just &nbsp
         # Span where not [0-9]+.
-        nbsps = re.compile("(nbspb;)+")
-        number = re.compile("^[0-9]+.$")
-        recommended_action = re.compile(
+        recommended_action_re = re.compile(
             r"Recommended Actions?\W*:?", re.RegexFlag.IGNORECASE)
-        staff_recommends = re.compile(
+        staff_recommends_re = re.compile(
             r"Staff recommends (that (the)? city council)?", re.RegexFlag.IGNORECASE)
         ps = recommendations_data.find_all('p')
         list_actions = recommendations_data.find('ol')
@@ -293,40 +297,28 @@ class SantaMonicaScraper(EngageScraper):
             next = list_actions.find('li')
             while next is not None:
                 if next.name == 'ol':
-
                     recommendations[-1] += " "+unicodedata.normalize(
                         "NFKD", next.get_text()).strip()
                 else:
-
                     recommendations.append(" "+unicodedata.normalize(
                         "NFKD", next.get_text().strip()))
                 next = next.next_sibling
         else:
             for p in ps:
                 current_recommendation = ""
-                spans = p.find_all('span')
-                for span in spans:
-                    text = span.get_text()
-                    text = unicodedata.normalize("NFKD", text)
-                    text = recommended_action.sub("", text)
-                    text = staff_recommends.sub("", text)
-                    text = nbsps.sub("", text)
-                    text = text.strip(" \n:").strip()
-                    if text == "":
-                        text = " "
-                    if text is not None and not number.search(text):
-                        if current_recommendation and current_recommendation[-1] != " " and check_last_word(current_recommendation):
-                            current_recommendation += " " + text
-                        else:
-                            current_recommendation += text
-                if current_recommendation:
-                    current_recommendation = current_recommendation[0].upper(
-                    ) + current_recommendation[1:]
-                    recommendations.append(current_recommendation)
+                p_text = unicodedata.normalize("NFKD", p.get_text())
+                if staff_recommends_re.search(p_text) or recommended_action_re.search(p_text):
+                    continue
+                p_text = SPACE_REGEX.sub(" ", p_text)
+                p_text = ITEM_REGEX.sub("", p_text)
+                if EMPTY_REGEX.search(p_text) or p_text == "":
+                    continue
+                recommendations.append(p_text.strip())
         return recommendations
 
     def _process_span(self, span):
         processed_span = SPACE_REGEX.sub(' ', span)
+        processed_span = DOT_REGEX.sub("", processed_span)
         return processed_span
 
     def _process_spans(self, spans):
@@ -465,7 +457,8 @@ class SantaMonicaScraper(EngageScraper):
                             log.info(es_load)
                 except Exception as itemExc:
                     agendaitem = item["agenda_item_id"]
-                    log.error(f"Could not add item {agendaitem} with {itemExc}")
+                    log.error(
+                        f"Could not add item {agendaitem} with {itemExc}")
         except Exception as exc:
             log.error(
                 "Something happened when adding agenda items from agenda {}: {}".format(agenda_saved.id, str(exc)))
