@@ -9,7 +9,7 @@ ES_INDEX_NAME = os.environ.get('ES_INDEX_NAME', 'agenda_items')
 class ElasticsearchUtility():
     def __init__(self):
         # Check if ES_INDEX_NAME exists, if not, create it
-        agenda_items = {
+        self._agenda_items = {
             "settings": {
                 "number_of_shards": 1
             },
@@ -59,45 +59,50 @@ class ElasticsearchUtility():
                 }
             }
         }
-        r = requests.head(f"http://{ES_HOSTNAME}/{ES_INDEX_NAME}:9200")
-        self.status = r.status_code
+        r = requests.head(f"http://{ES_HOSTNAME}:9200/{ES_INDEX_NAME}?allow_no_indices=false")
+        self.status_code = r.status_code
+        if self.status_code != requests.codes.ok:
+            reqPut = requests.put(f"http://{ES_HOSTNAME}:9200/{ES_INDEX_NAME}", json=self._agenda_items)
+            responsePut = json.loads(reqPut.text)
+            if not responsePut["acknowledged"]:
+                raise RuntimeError(f'Could not create ES index {reqPut.text}')
 
-    def postItems(self, items=None):
+    def postItem(self, item=None):
         """
         helper function to load scrapped agenda item to elastic search
 
             Args: 
-                items: dict, key/value pairs representing elasticseaech index fileds. The accepted
+                item: dict, key/value pairs representing elasticseaech index fileds. The accepted
                         keys are:
                             - date: date, meeting date
                             - agenda_item_id: int, agenda item id
                             - agenda_id: int, the id of the specific meeting
                             - title: str, the title of the agenda
                             - recommendations: str, the propposed recommendation from the city
-                            - body: str, details about the items
+                            - body: str, details about the item
                             - department: list, all departments concerned with the item
                             - sponsors: str,
                             - tags: None
                             - committee: str, the name of the comittee,
                             - committee_id: int, the id of the comitte
             Returns:
-                str, 
+                bool, True is successfully added item 
         """
 
-        url = f'http://{ES_ENPOINT_NAME}:9200/{ES_INDEX_NAME}/_doc/'
+        url = f'http://{ES_HOSTNAME}:9200/{ES_INDEX_NAME}/_doc/'
 
         payload = {
-            'date': items.get('date'),
-            'agenda_item_id': int(items.get('agenda_item_id')),
-            'agenda_id': items.get('agenda_id'),
-            'title': items.get('title'),
-            'recommendations': items.get('recommendations'),
-            'body': items.get('body'),
-            'department': items.get('department').split(','),
-            'sponsors': items.get('sponsors'),
-            'tags': items.get('tags'),
-            'committee': items.get('committee'),
-            'committee_id': items.get('committee_id'),
+            'date': item.get('date'),
+            'agenda_item_id': int(item.get('agenda_item_id')),
+            'agenda_id': item.get('agenda_id'),
+            'title': item.get('title'),
+            'recommendations': item.get('recommendations'),
+            'body': item.get('body'),
+            'department': item.get('department').split(','),
+            'sponsors': item.get('sponsors'),
+            'tags': item.get('tags'),
+            'committee': item.get('committee'),
+            'committee_id': item.get('committee_id'),
         }
 
         r = requests.post(url, json=payload)
